@@ -7,7 +7,7 @@ RDF::Trine::Parser - RDF Parser class
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser version 1.000
+This document describes RDF::Trine::Parser version 1.002
 
 =head1 SYNOPSIS
 
@@ -53,7 +53,7 @@ our %format_uris;
 our %encodings;
 
 BEGIN {
-	$VERSION	= '1.000';
+	$VERSION	= '1.002';
 	can_load( modules => {
 		'Data::UUID'	=> undef,
 		'UUID::Tiny'	=> undef,
@@ -66,8 +66,6 @@ use LWP::UserAgent;
 use RDF::Trine::Error qw(:try);
 use RDF::Trine::Parser::NTriples;
 use RDF::Trine::Parser::NQuads;
-use RDF::Trine::Parser::Turtle;
-use RDF::Trine::Parser::TriG;
 use RDF::Trine::Parser::RDFXML;
 use RDF::Trine::Parser::RDFJSON;
 use RDF::Trine::Parser::RDFa;
@@ -208,7 +206,8 @@ sub parse_url_into_model {
 			$data	= decode( $e, $content );
 		}
 		
-		my $parser	= $pclass->new();
+		# pass %args in here too so the constructor can take its pick
+		my $parser	= $pclass->new(%args);
 		my $ok	= 0;
 		try {
 			$parser->parse_into_model( $url, $data, $model, %args );
@@ -366,7 +365,7 @@ sub parse_file {
 			my $pclass = $self->guess_parser_by_filename( $filename );
 			$self = $pclass->new() if ($pclass and $pclass->can('new'));
 		}
-		open( $fh, '<:utf8', $filename ) or throw RDF::Trine::Error::ParserError -text => $!;
+		open( $fh, '<:encoding(UTF-8)', $filename ) or throw RDF::Trine::Error::ParserError -text => $!;
 	}
 
 	if ($self and $self->can('parse')) {
@@ -397,9 +396,8 @@ sub new_bnode_prefix {
 		my $uuid	= $ug->to_string( $ug->create() );
 		$uuid		=~ s/-//g;
 		return 'b' . $uuid;
-	} elsif (defined($UUID::Tiny::VERSION) && ($] < 5.014000)) { # UUID::Tiny 1.03 isn't working nice with thread support in Perl 5.14. When this is fixed, this may be removed and dep added.
-		no strict 'subs';
-		my $uuid	= UUID::Tiny::create_UUID_as_string(UUID::Tiny::UUID_V1);
+	} elsif (defined($UUID::Tiny::VERSION) && ($] < 5.010000)) { # UUID::Tiny 1.03 isn't working nice with thread support in Perl 5.14. When this is fixed, this may be removed and dep added.
+		my $uuid	= UUID::Tiny::create_UUID_as_string(UUID::Tiny::UUID_V1());
 		$uuid		=~ s/-//g;
 		return 'b' . $uuid;
 	} else {
