@@ -4,11 +4,27 @@ RDF::Trine::Store::DBI - Persistent RDF storage based on DBI
 
 =head1 VERSION
 
-This document describes RDF::Trine::Store::DBI version 0.135
+This document describes RDF::Trine::Store::DBI version 1.002
 
 =head1 SYNOPSIS
 
- use RDF::Trine::Store::DBI;
+  use RDF::Trine::Store::DBI;
+  
+  my $user = 'me';
+  my $pass = 'secret';
+  my $modelname = 'mymodel';
+
+  # First, construct a DBI connection to your database
+  my $dsn = "DBI:mysql:database=perlrdf";
+  my $dbh = DBI->connect( $dsn, $user, $pass );
+  
+  # Second, create a new Store object with the database connection
+  # and specifying (by name) which model in the Store you want to use
+  my $store = RDF::Trine::Store::DBI->new( $modelname, $dbh );
+  
+  # Finally, wrap the Store objec into a Model, and use it to access your data
+  my $model = RDF::Trine::Model->new($store);
+  print $model->size . " RDF statements in store\n";
 
 =head1 DESCRIPTION
 
@@ -25,6 +41,8 @@ no warnings 'redefine';
 use base qw(RDF::Trine::Store);
 
 use DBI;
+use DBIx::Connector;
+
 use Carp;
 use DBI;
 use Scalar::Util qw(blessed reftype refaddr);
@@ -47,7 +65,7 @@ use RDF::Trine::Store::DBI::Pg;
 
 our $VERSION;
 BEGIN {
-	$VERSION	= "0.135";
+	$VERSION	= "1.002";
 	my $class	= __PACKAGE__;
 	$RDF::Trine::Store::STORE_CLASSES{ $class }	= $VERSION;
 }
@@ -105,7 +123,7 @@ Initialize the store with a L<DBI::db> object.
 
 sub new {
 	my $class	= shift;
-	my $dbh;
+	my ($dbh, $conn);
 	
 	my $l		= Log::Log4perl->get_logger("rdf.trine.store.dbi");
 	
@@ -114,7 +132,7 @@ sub new {
 	if (scalar(@_) == 0) {
 		$l->trace("trying to construct a temporary model");
 		my $dsn		= "dbi:SQLite:dbname=:memory:";
-		$dbh		= DBI->connect( $dsn, '', '' );
+		$conn		= DBIx::Connector->new( $dsn, '', '' );
 		$class		= 'RDF::Trine::Store::DBI::SQLite';
 	} elsif (blessed($_[0]) and $_[0]->isa('DBI::db')) {
 		$l->trace("got a DBD handle");
@@ -127,6 +145,8 @@ sub new {
 		} elsif ($name eq 'SQLite') {
 			$class	= 'RDF::Trine::Store::DBI::SQLite';
 		}
+	} elsif (blessed($_[0]) and $_[0]->isa('DBIx::Connector')) {
+		$conn	= shift;
 	} else {
 		my $dsn		= shift;
 		my $user	= shift;
@@ -141,8 +161,8 @@ sub new {
 			$pass	= '';
 		}
 		$l->trace("Connecting to $dsn ($user, $pass)");
-		$dbh		= DBI->connect( $dsn, $user, $pass );
-		unless ($dbh) {
+		$conn		= DBIx::Connector->new( $dsn, $user, $pass );
+		unless ($conn) {
 			throw RDF::Trine::Error::DatabaseError -text => "Couldn't connect to database: " . DBI->errstr;
 		}
 	}
@@ -150,6 +170,7 @@ sub new {
 	my $self	= bless( {
 		model_name				=> $name,
 		dbh						=> $dbh,
+		conn					=> $conn,
 		statements_table_prefix	=> 'Statements',
 		%args
 	}, $class );
@@ -196,8 +217,8 @@ sub nuke {
 	my $id		= _mysql_hash( $name );
 	my $l		= Log::Log4perl->get_logger("rdf.trine.store.dbi");
 	
-	$dbh->do( "DROP TABLE Statements${id};" ) || do { $l->trace( $dbh->errstr ); return undef };
-	$dbh->do( "DELETE FROM Models WHERE ID = ${id}") || do { $l->trace( $dbh->errstr ); $dbh->rollback; return undef };
+	$dbh->do( "DROP TABLE Statements${id};" ) || do { $l->trace( $dbh->errstr ); return };
+	$dbh->do( "DELETE FROM Models WHERE ID = ${id}") || do { $l->trace( $dbh->errstr ); $dbh->rollback; return };
 }
 
 =item C<< supports ( [ $feature ] ) >>
@@ -289,7 +310,7 @@ sub get_statements {
 	my $sub		= sub {
 NEXTROW:
 		my $row	= $sth->fetchrow_hashref;
-		return undef unless (defined $row);
+		return unless (defined $row);
 		my @triple;
 		my $temp_var_count	= 1;
 		my @nodes	= ($st->nodes)[ $use_quad ? (0..3) : (0..2) ];
@@ -468,26 +489,15 @@ sub add_statement {
 # 	Carp::confess unless (blessed($stmt));
 	my $stable	= $self->statements_table;
 	my @nodes	= $stmt->nodes;
-	foreach my $n (@nodes) {
-		$self->_add_node( $n );
-	}
+	my @values = map { $self->_add_node( $_ ) } @nodes;
 	
-	my @values	= map { $self->_mysql_node_hash( $_ ) } @nodes;
 	if ($stmt->isa('RDF::Trine::Statement::Quad')) {
 		if (blessed($context)) {
 			throw RDF::Trine::Error::MethodInvocationError -text => "add_statement cannot be called with both a quad and a context";
 		}
 		$context	= $stmt->context;
 	} else {
-		my $cid		= do {
-			if ($context) {
-				$self->_add_node( $context );
-				$self->_mysql_node_hash( $context );
-			} else {
-				0
-			}
-		};
-		push(@values, $cid);
+		push @values, ($context ? $self->_add_node($context) : 0);
 	}
 	my $sql	= "SELECT 1 FROM ${stable} WHERE Subject = ? AND Predicate = ? AND Object = ? AND Context = ?";
 	my $sth	= $dbh->prepare( $sql );
@@ -576,7 +586,7 @@ sub _add_node {
 	my @cols;
 	my $table;
 	my %values;
-	return 1 if ($node->is_nil);
+	return $hash if ($node->is_nil);
 	if ($node->is_blank) {
 		$table	= "Bnodes";
 		@cols	= qw(ID Name);
@@ -607,6 +617,7 @@ sub _add_node {
 		my $sth	= $dbh->prepare( $sql );
 		$sth->execute( @values );
 	}
+	return $hash;
 }
 
 =item C<< count_statements ($subject, $predicate, $object) >>
@@ -1204,11 +1215,13 @@ sub _mysql_hash_pp {
 }
 
 BEGIN {
+	## no critic
 	eval "use RDF::Trine::XS;";
 	no strict 'refs';
 	*{ '_mysql_hash' }	= (RDF::Trine::XS->can('hash'))
 		? \&RDF::Trine::XS::hash
 		: \&_mysql_hash_pp;
+	## use critic
 }
 
 =item C<< _mysql_node_hash ( $node ) >>
@@ -1245,7 +1258,7 @@ sub _mysql_node_hash {
 		$data	= sprintf("L%s<%s>%s", $value, $lang, $dt);
 #		warn "($data)";
 	} else {
-		return undef;
+		return;
 	}
 	my $hash;
 	$hash	= _mysql_hash( $data );
@@ -1333,8 +1346,12 @@ Returns the underlying DBI database handle.
 
 sub dbh {
 	my $self	= shift;
-	my $dbh		= $self->{dbh};
-	return $dbh;
+	if (my $conn = $self->{conn}) {
+		return $conn->dbh;
+	} else {
+		my $dbh		= $self->{dbh};
+		return $dbh;
+	}
 }
 
 sub _debug {
@@ -1367,7 +1384,7 @@ sub init {
 	
 	unless ($self->_table_exists("Literals")) {
 		$dbh->begin_work;
-		$dbh->do( <<"END" ) || do { $l->trace( $dbh->errstr ); $dbh->rollback; return undef };
+		$dbh->do( <<"END" ) || do { $l->trace( $dbh->errstr ); $dbh->rollback; return };
 			CREATE TABLE Literals (
 				ID NUMERIC(20) PRIMARY KEY,
 				Value text NOT NULL,
@@ -1375,19 +1392,19 @@ sub init {
 				Datatype text NOT NULL DEFAULT ''
 			);
 END
-		$dbh->do( <<"END" ) || do { $l->trace( $dbh->errstr ); $dbh->rollback; return undef };
+		$dbh->do( <<"END" ) || do { $l->trace( $dbh->errstr ); $dbh->rollback; return };
 			CREATE TABLE Resources (
 				ID NUMERIC(20) PRIMARY KEY,
 				URI text NOT NULL
 			);
 END
-		$dbh->do( <<"END" ) || do { $l->trace( $dbh->errstr ); $dbh->rollback; return undef };
+		$dbh->do( <<"END" ) || do { $l->trace( $dbh->errstr ); $dbh->rollback; return };
 			CREATE TABLE Bnodes (
 				ID NUMERIC(20) PRIMARY KEY,
 				Name text NOT NULL
 			);
 END
-		$dbh->do( <<"END" ) || do { $l->trace( $dbh->errstr ); $dbh->rollback; return undef };
+		$dbh->do( <<"END" ) || do { $l->trace( $dbh->errstr ); $dbh->rollback; return };
 			CREATE TABLE Models (
 				ID NUMERIC(20) PRIMARY KEY,
 				Name text NOT NULL
@@ -1398,7 +1415,7 @@ END
 	}
 	
 	unless ($self->_table_exists("Statements${id}")) {
-		$dbh->do( <<"END" ) || do { $l->trace( $dbh->errstr ); return undef };
+		$dbh->do( <<"END" ) || do { $l->trace( $dbh->errstr ); return };
 			CREATE TABLE Statements${id} (
 				Subject NUMERIC(20) NOT NULL,
 				Predicate NUMERIC(20) NOT NULL,
@@ -1407,7 +1424,7 @@ END
 				PRIMARY KEY (Subject, Predicate, Object, Context)
 			);
 END
-# 		$dbh->do( "DELETE FROM Models WHERE ID = ${id}") || do { $l->trace( $dbh->errstr ); $dbh->rollback; return undef };
+# 		$dbh->do( "DELETE FROM Models WHERE ID = ${id}") || do { $l->trace( $dbh->errstr ); $dbh->rollback; return };
 		$dbh->do( "INSERT INTO Models (ID, Name) VALUES (${id}, ?)", undef, $name );
 	}
 	
@@ -1416,7 +1433,7 @@ END
 sub _table_exists {
 	my $self	= shift;
 	my $name	= shift;
-	my $dbh		= $self->{dbh};
+	my $dbh		= $self->dbh;
 	my $type	= 'TABLE';
 	my $sth		= $dbh->table_info(undef, undef, $name, 'TABLE');
 	my $row		= $sth->fetchrow_hashref;
@@ -1425,8 +1442,7 @@ sub _table_exists {
 
 sub _cleanup {
 	my $self	= shift;
-	if ($self->{dbh}) {
-		my $dbh		= $self->{dbh};
+	if (my $dbh = $self->dbh) {
 		my $name	= $self->{model_name};
 		my $id		= _mysql_hash( $name );
 		if ($self->{ remove_store }) {
@@ -1455,7 +1471,7 @@ sub DESTROY {
 	my $self	= shift;
 	our $IGNORE_CLEANUP;
 	if ($IGNORE_CLEANUP) {
-		$self->{dbh}->{InactiveDestroy}	= 1;
+		$self->dbh->{InactiveDestroy}	= 1;
 	} else {
 		$self->_cleanup;
 	}
@@ -1468,8 +1484,8 @@ __END__
 
 =head1 BUGS
 
-Please report any bugs or feature requests to
-C<< <gwilliams@cpan.org> >>.
+Please report any bugs or feature requests to through the GitHub web interface
+at L<https://github.com/kasei/perlrdf/issues>.
 
 =head1 AUTHOR
 
@@ -1477,7 +1493,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2010 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
